@@ -6,8 +6,7 @@ import (
 )
 
 type Os struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	Icon string
 }
@@ -66,6 +65,7 @@ func (oi *Os) getDistroIcon(distro string) string {
 		"endeavouros":         "\uF322",
 		"fedora":              "\uF30a",
 		"gentoo":              "\uF30d",
+		"kali":                "\uf327",
 		"mageia":              "\uF310",
 		"manjaro":             "\uF312",
 		"mint":                "\uF30e",
@@ -91,8 +91,3 @@ func (oi *Os) getDistroIcon(distro string) string {
 
 	return oi.props.GetString(Linux, "\uF17C")
 }
-
-func (oi *Os) Init(props properties.Properties, env runtime.Environment) {
-	oi.props = props
-	oi.env = env
-}
