@@ -16,6 +16,10 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
+const (
+	regexPrefix = "re:"
+)
+
 type Folder struct {
 	Name    string
 	Path    string
@@ -114,6 +118,8 @@ const (
 	GitDirFormat properties.Property = "gitdir_format"
 	// DisplayCygpath transforms the path to a cygpath format
 	DisplayCygpath properties.Property = "display_cygpath"
+	// DisplayRoot indicates if the linux root slash should be displayed
+	DisplayRoot properties.Property = "display_root"
 )
 
 func (pt *Path) Template() string {
@@ -304,15 +310,10 @@ func (pt *Path) getFolderSeparator() string {
 }
 
 func (pt *Path) getMixedPath() string {
-	root := pt.root
-	folders := pt.Folders
 	threshold := int(pt.props.GetFloat64(MixedThreshold, 4))
 	folderIcon := pt.props.GetString(FolderIcon, "..")
 
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	var elements []string
 
@@ -330,14 +331,9 @@ func (pt *Path) getMixedPath() string {
 }
 
 func (pt *Path) getAgnosterPath() string {
-	root := pt.root
-	folders := pt.Folders
 	folderIcon := pt.props.GetString(FolderIcon, "..")
 
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	var elements []string
 
@@ -354,14 +350,9 @@ func (pt *Path) getAgnosterPath() string {
 }
 
 func (pt *Path) getAgnosterLeftPath() string {
-	root := pt.root
-	folders := pt.Folders
 	folderIcon := pt.props.GetString(FolderIcon, "..")
 
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	var elements []string
 	if len(folders) == 0 {
@@ -406,13 +397,7 @@ func (pt *Path) getRelevantLetter(folder *Folder) string {
 }
 
 func (pt *Path) getLetterPath() string {
-	root := pt.root
-	folders := pt.Folders
-
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	root = pt.getRelevantLetter(&Folder{Name: root})
 
@@ -431,14 +416,11 @@ func (pt *Path) getLetterPath() string {
 }
 
 func (pt *Path) getUniqueLettersPath(maxWidth int) string {
-	root := pt.root
-	folders := pt.Folders
+	dr := pt.props.GetBool(DisplayRoot, false)
+	log.Debugf("%t", dr)
 	separator := pt.getFolderSeparator()
 
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	folderNames := folders.List()
 
@@ -499,25 +481,13 @@ func (pt *Path) getUniqueLettersPath(maxWidth int) string {
 }
 
 func (pt *Path) getAgnosterFullPath() string {
-	root := pt.root
-	folders := pt.Folders
-
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	return pt.colorizePath(root, folders.List())
 }
 
 func (pt *Path) getAgnosterShortPath() string {
-	root := pt.root
-	folders := pt.Folders
-
-	if pt.isRootFS(root) {
-		root = folders[0].Name
-		folders = folders[1:]
-	}
+	root, folders := pt.getPaths()
 
 	maxDepth := pt.props.GetInt(MaxDepth, 1)
 	if maxDepth < 1 {
@@ -604,12 +574,16 @@ func (pt *Path) setMappedLocations() {
 			continue
 		}
 
+		if !strings.HasPrefix(location, regexPrefix) {
+			location = pt.normalize(location)
+		}
+
 		// When two templates resolve to the same key, the values are compared in ascending order and the latter is taken.
-		if v, exist := mappedLocations[pt.normalize(location)]; exist && value <= v {
+		if v, exist := mappedLocations[location]; exist && value <= v {
 			continue
 		}
 
-		mappedLocations[pt.normalize(location)] = value
+		mappedLocations[location] = value
 	}
 
 	pt.mappedLocations = mappedLocations
@@ -643,8 +617,38 @@ func (pt *Path) replaceMappedLocations(inputPath string) (string, string) {
 		return strings.NewReplacer("<", "<<>", ">", "<>>").Replace(path)
 	}
 
+	handleRegex := func(key string) (string, bool) {
+		if !strings.HasPrefix(key, regexPrefix) {
+			return "", false
+		}
+
+		input := strings.ReplaceAll(inputPath, `\`, `/`)
+		pattern := key[len(regexPrefix):]
+
+		// Add (?i) at the start of the pattern for case-insensitive matching on Windows
+		if pt.windowsPath || (pt.env.IsWsl() && strings.HasPrefix(input, "/mnt/")) {
+			pattern = "(?i)" + pattern
+		}
+
+		match, OK := regex.FindStringMatch(pattern, input, 1)
+		if !OK {
+			return "", false
+		}
+
+		// Replace the first match with the mapped location.
+		input = strings.Replace(input, match, pt.mappedLocations[key], 1)
+		input = path.Clean(input)
+
+		return input, true
+	}
+
 	for _, key := range keys {
+		if input, OK := handleRegex(key); OK {
+			return pt.parsePath(input)
+		}
+
 		keyRoot, keyRelative := pt.parsePath(key)
+
 		matchSubFolders := strings.HasSuffix(keyRelative, pt.pathSeparator+"*")
 
 		if matchSubFolders {
@@ -724,8 +728,25 @@ func (pt *Path) parsePath(inputPath string) (string, string) {
 	return root, relative
 }
 
-func (pt *Path) isRootFS(inputPath string) bool {
-	return len(inputPath) == 1 && path.IsSeparator(inputPath[0])
+func (pt *Path) getPaths() (string, Folders) {
+	root := pt.root
+	folders := pt.Folders
+
+	isRootFS := func(inputPath string) bool {
+		displayRoot := pt.props.GetBool(DisplayRoot, false)
+		if displayRoot {
+			return false
+		}
+
+		return len(inputPath) == 1 && path.IsSeparator(inputPath[0])
+	}
+
+	if isRootFS(root) {
+		root = folders[0].Name
+		folders = folders[1:]
+	}
+
+	return root, folders
 }
 
 func (pt *Path) endWithSeparator(inputPath string) bool {
